@@ -46,7 +46,7 @@ Handel::Cart::Item - Module representing an indivudal shopping cart line item
 
 =head1 VERSION
 
-    $Id: Item.pm 46 2004-12-31 20:38:58Z claco $
+    $Id: Item.pm 60 2005-01-10 02:18:33Z claco $
 
 =head1 SYNOPSIS
 
@@ -93,15 +93,35 @@ You can create a new C<Handel::Cart::Item> object by call the C<new> method:
         quantity => 1
     });
 
+    $item->quantity(2);
+
+    print $item->total;
+
 This is a lazy operation. No actual item record is created until the item object
 is passed into the carts C<add> method.
 
 =head1 METHODS
 
+=head2 C<$item-E<gt>sku>
+
+Returns or sets the sku (stock keeping unit/part number) for the cart item.
+
+=head2 C<$item-E<gt>quantity>
+
+Returns or sets the quantity the cart item.
+
+=head2 C<$item-E<gt>price>
+
+Returns or sets the price for the cart item.
+
 =head2 C<$item-E<gt>total>
 
-Returns the total price for the cart item. This is really just quantity*total
-and is provided for convenience.
+Returns the total price for the cart item. This is really just
+quantity*total and is provided for convenience.
+
+=head2 C<$item-E<gt>description>
+
+Returns or sets the description for the cart item.
 
 =head1 SEE ALSO
 
@@ -117,3 +137,4 @@ L<Handel::Cart>
 
 
 
+
